# $Id: autogen.sh,v 1.1.1.3 2004/01/30 08:04:33 rousseau Exp $

set -x

rm -f configure Makefile Makefile.in config.h.in
aclocal

libtoolize --force --copy

autoheader
automake --add-missing --foreign
autoconf

